API Documentation
=================

.. toctree::
   :maxdepth: 2

   Class Reference <classes.rst>
   AFL Operator Reference <afl.rst>
   Robust AFL wrappers <robust.rst>
   Schema Manipulation Utilities <schema_utils.rst>
